# Reference implementations of common solar position algorithms
solposx is a Python package for calculating solar position angles and comparing solar position algorithms.

## Documentation
The documentation can be found at [readthedocs](https://solposx.readthedocs.io/).

## Installation and dependencies
The package can be installed using pip:

    pip install solposx

## Contributing
Contributions to the repository, e.g., bug fixes, improvements to the documentation, or the addition of new algorithms, are more than welcome.

## License
[BSD 3-clause](LICENSE).
